@@ -9,7 +9,7 @@
 
 from __future__ import with_statement
 
-__version__ = '0.5.22'
+__version__ = '0.5.24'
 
 # import sip
 # sip.setapi('QString', 2)
@@ -260,6 +260,7 @@ class KhweeteurWin(QMainWindow):
         self.view.clicked.connect(self.switch_tb_action)
 
         self.toolbar = QToolBar('Toolbar')
+#        self.toolbar.setMovable(False)
         self.addToolBar(Qt.BottomToolBarArea, self.toolbar)
 
         self.toolbar_mode = 0  # 0 - Default , 1 - Edit, 2 - Action
@@ -358,8 +359,8 @@ class KhweeteurWin(QMainWindow):
         self.show()
 
         self.model.load('HomeTimeline',limit=5)
-        QTimer.singleShot(100,self.post_init_2)
-        QTimer.singleShot(500,self.post_init_3)
+        QTimer.singleShot(0,self.post_init_2)
+        QTimer.singleShot(0,self.post_init_3)
         QApplication.processEvents()
 
     @Slot()
@@ -548,11 +549,12 @@ class KhweeteurWin(QMainWindow):
     def listen_dbus(self):
         import dbus
         import dbus.service
-        from dbusobj import KhweeteurDBus
         from dbushandler import KhweeteurDBusHandler
-        from dbus.mainloop.qt import DBusQtMainLoop
-        self.dbus_loop = DBusQtMainLoop()
-        dbus.set_default_main_loop(self.dbus_loop)
+        import dbus.mainloop.glib
+        #from dbus.mainloop.qt import DBusQtMainLoop
+        #self.dbus_loop = DBusQtMainLoop()
+        dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
+        #dbus.set_default_main_loop(self.dbus_loop)
         self.bus = dbus.SessionBus()
 
         # Connect the new tweet signal
@@ -566,9 +568,8 @@ class KhweeteurWin(QMainWindow):
                                      dbus_interface='net.khertan.Khweeteur',
                                      signal_name='refresh_ended')
         self.dbus_handler = KhweeteurDBusHandler(self)
+        self.dbus_handler.attach_win(self)
         self.activated_by_dbus.connect(self.activateWindow)
-        dbusobj = KhweeteurDBus()
-        dbusobj.attach_win(self)
 
     def stop_spinning(self):
         try:
